@@ -93,10 +93,10 @@ Some generic base classes and functions can be found in L{zim.utils}
 
 
 # Bunch of meta data, used at least in the about dialog
-__version__ = '0.75.2'
+__version__ = '0.76.3'
 __url__ = 'https://www.zim-wiki.org'
 __author__ = 'Jaap Karssenberg <jaap.karssenberg@gmail.com>'
-__copyright__ = 'Copyright 2008 - 2023 Jaap Karssenberg <jaap.karssenberg@gmail.com>'
+__copyright__ = 'Copyright 2008 - 2025 Jaap Karssenberg <jaap.karssenberg@gmail.com>'
 __license__ = '''\
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -191,7 +191,7 @@ if os.name == 'nt':
 	# Windows specific environment variables
 	# os.environ does not support setdefault() ...
 	if not 'USER' in os.environ or not os.environ['USER']:
-		os.environ['USER'] = os.environ['USERNAME']
+		os.environ['USER'] = os.environ.get('USERNAME')
 
 	if not 'HOME' in os.environ or not os.environ['HOME']:
 		if 'USERPROFILE' in os.environ:
@@ -209,3 +209,4 @@ if not os.path.isdir(os.environ['HOME']):
 if not 'USER' in os.environ or not os.environ['USER']:
 	os.environ['USER'] = os.path.basename(os.environ['HOME'])
 	logger.info('Environment variable $USER was not set, set to "%s"', os.environ['USER'])
+
