@@ -41,7 +41,6 @@
 
 
 import os
-import hashlib
 import time
 import threading
 
@@ -59,22 +58,17 @@ logger = logging.getLogger('zim.plugins.attachmentbrowser')
 
 import zim
 
+from zim.newfs.base import md5_for_unsave_usage
+
 from zim.config import XDG_CACHE_HOME
-from zim.gui.widgets import rotate_pixbuf
-
+from zim.fs import adapt_from_oldfs
 from zim.newfs import LocalFile, LocalFolder
+from zim.gui.base.images import image_file_load_pixels
 
 
-LOCAL_THUMB_STORAGE_NORMAL = XDG_CACHE_HOME.subdir('thumbnails/normal')
-LOCAL_THUMB_STORAGE_LARGE = XDG_CACHE_HOME.subdir('thumbnails/large')
-LOCAL_THUMB_STORAGE_FAIL = XDG_CACHE_HOME.subdir('thumbnails/fail/zim-%s' % zim.__version__)
-
-## XXX zim.fs --> zim.newfs
-LOCAL_THUMB_STORAGE_NORMAL = LocalFolder(LOCAL_THUMB_STORAGE_NORMAL.path)
-LOCAL_THUMB_STORAGE_LARGE = LocalFolder(LOCAL_THUMB_STORAGE_LARGE.path)
-LOCAL_THUMB_STORAGE_FAIL = LocalFolder(LOCAL_THUMB_STORAGE_FAIL.path)
-##
-
+LOCAL_THUMB_STORAGE_NORMAL = XDG_CACHE_HOME.folder('thumbnails/normal')
+LOCAL_THUMB_STORAGE_LARGE = XDG_CACHE_HOME.folder('thumbnails/large')
+LOCAL_THUMB_STORAGE_FAIL = XDG_CACHE_HOME.folder('thumbnails/fail/zim-%s' % zim.__version__)
 
 THUMB_SIZE_NORMAL = 128
 THUMB_SIZE_LARGE = 256
@@ -90,10 +84,8 @@ def pixbufThumbnailCreator(file, thumbfile, thumbsize):
 	'''Thumbnailer implementation that uses the C{GdkPixbuf.Pixbuf}
 	functions to create the thumbnail.
 	'''
-	if not (isinstance(file, LocalFile) and isinstance(thumbfile, LocalFile)) \
-	or (os.name == 'nt' and file.basename.endswith('.svg')):
-		# .svg causes segfaults on windows, even if svg support enabled
-		raise ThumbnailCreatorFailure
+	if not (isinstance(file, LocalFile) and isinstance(thumbfile, LocalFile)):
+		raise ThumbnailCreatorFailure()
 
 	tmpfile = thumbfile.parent().file('zim-thumb.new~')
 	options = { # no unicode allowed in options!
@@ -106,12 +98,11 @@ def pixbufThumbnailCreator(file, thumbfile, thumbsize):
 		optionskeys.append(k)
 		optionsvalues.append(v)
 	try:
-		pixbuf = GdkPixbuf.Pixbuf.new_from_file_at_size(file.path, thumbsize, thumbsize)
-		pixbuf = rotate_pixbuf(pixbuf)
+		pixbuf = image_file_load_pixels(file, thumbsize, thumbsize, fail_silent=True)
 		pixbuf.savev(tmpfile.path, 'png', optionskeys, optionsvalues)
 		_atomic_rename(tmpfile.path, thumbfile.path)
 	except:
-		raise ThumbnailCreatorFailure
+		raise ThumbnailCreatorFailure()
 	else:
 		return pixbuf
 
@@ -241,7 +232,7 @@ class ThumbnailManager(object):
 		@param size: thumbnail size in pixels (C{THUMB_SIZE_NORMAL}, C{THUMB_SIZE_LARGE}, or integer)
 		@returns: a L{File} object
 		'''
-		basename = hashlib.md5(file.uri.encode('ascii')).hexdigest() + '.png'
+		basename = md5_for_unsave_usage(file.uri.encode('ascii')).hexdigest() + '.png'
 			# file.uri should already be URL encoded for unicode characters - use 'ascii' to check
 		if size <= THUMB_SIZE_NORMAL:
 			return LOCAL_THUMB_STORAGE_NORMAL.file(basename)
@@ -288,7 +279,7 @@ class ThumbnailManager(object):
 		@raises ThumbnailCreatorFailure: if creation fails unexpectedly
 		'''
 		if not isinstance(file, LocalFile):
-			raise None(None)
+			raise ThumbnailCreatorFailure()
 
 		thumbfile = self.get_thumbnail_file(file, size)
 		thumbsize = THUMB_SIZE_NORMAL if size <= THUMB_SIZE_NORMAL else THUMB_SIZE_LARGE
